# ng-angular-popup

This library was generated with [Angular CLI](https://github.com/angular/angular-cli) version 18.0.1.

Code Implementation : [Let's Program Blog](https://letsprogram.in/blog/647990c15960050b58aca375)

## Changelog

- Removed the object way of configuration
- Removed dependency of font-awesome
- Updated the library with Angular v18
- Signal usage for better compatibility with zoneless

## Features

- Easy to integrate
- Supports success, error, info and warning toaster messages
- Easy to configure
- supports title, message , position, duration
- New UI design with better accessibility

## Dependencies
Recommend to use the latest version of ng-angular-popup
More Compatible with Latest version of Angular

| ng-angular-popup | Angular     |
| ---------------- | ----------- |
| current          | >= 16.x     |

For Lower version of Angular use
```
npm i ng-angular-popup -f
```
## Install

```
npm i ng-angular-popup
```

## Setup

- Add NgToasterModule to App NgModule

- import NgToastModule in app.module.ts
```typescript
import { NgModule } from '@angular/core';
import { HeaderComponent } from './component/header/header.component';
import { NgToastModule } from 'ng-angular-popup' // to be added

@NgModule({
  declarations: [
    HeaderComponent,

  ],
  imports: [
    NgToastModule // to be added
  ],

})
export class AppModule { }
```

- Add NgToasterModule to Standalone root component

- import NgToastModule in app.component.ts
```typescript
import { Component } from '@angular/core';
import { RouterOutlet } from '@angular/router';
import { NgToastModule } from 'ng-angular-popup' // to be added
import { ToasterPosition } from 'ng-toasty'; // to be added to load position enums

@Component({
  selector: 'app-root',
  standalone: true,
  imports: [RouterOutlet, NgToastModule],
  templateUrl: './app.component.html',
  styleUrl: './app.component.scss'
})
export class AppComponent {
  title = 'angular-v18-playground';
  ToasterPosition = ToasterPosition;
}

```
- use the selector <ng-toast></ng-toast> in app.component.html file
```html
<ng-toast />  <!-- takes default width of 350px and top-right position   -->
<ng-toast [width]="400" /> <!-- configure width   -->
<ng-toast [width]="300" [position]="ToasterPosition.TOP_CENTER" /> <!-- configure width with position   -->
```
## Use

```typescript
import { Component } from '@angular/core';
import { NgToastService } from 'ng-angular-popup'; //make sure to import service

@Component({
  selector: 'app-root',
  templateUrl: './app.component.html',
  styleUrls: ['./app.component.scss']
})
export class AppComponent {

  private = inject(NgToastService); //inject the service

  ngOnInit(): void {
  }

  error(){
    this.toast.danger("This is new error message"); // by default visible duration is 2000ms
  }

  success(){
    this.toast.success("This is new error Success", "SUCCESS", 5000) // message with title and 5000ms duration
  }

  info(){
    this.toast.info("This is new error Info", "INFO", 5000)
  }

  warning(){
    this.toast.warning("This is new Warning message", "WARNING", 5000)
  }

}
```

## FAQ

Check out article on 
[ng-angular-popup Integration with Angular](https://letsprogram.in/blog/647990c15960050b58aca375)

## License

MIT

---

> GitHub [@SashikumarYadav](https://github.com/yshashi) &nbsp;&middot;&nbsp;
> Blog [@LetsProgram](https://letsprogram.in/) &nbsp;&middot;&nbsp;
> LinkedIn [@SashikumarYadav](https://www.linkedin.com/in/sashikumar-yadav-93b621139/) &nbsp;&middot;&nbsp;
> Medium [@SashikumarYadav](https://medium.com/@yshashi30)
